infer_orientation_signs: Infer orientation signs for each observable indicator
Description
This helper analyzes observable indicators and returns a numeric vector
of 1 or -1 for use with the orientation_signs
argument in lpmec. Each sign is chosen so that the correlation
between the oriented indicator and either the outcome Y or the
first principal component of the indicators is positive.