| summary.lpmec | R Documentation |
Provides a comprehensive summary of bootstrapped LPMEC model results including OLS, IV, corrected, and Bayesian coefficient estimates with confidence intervals.
## S3 method for class 'lpmec'
summary(object, ...)
object |
An object of class |
... |
Additional arguments (currently unused). |
A data frame containing coefficient estimates, standard errors, and confidence intervals, returned invisibly. The data frame has rows for OLS, IV, Corrected IV, Corrected OLS, and Bayesian OLS estimates.
lpmec, print.lpmec, plot.lpmec
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.