Learn R Programming

lpmec (version 1.1.4)

summary.lpmec: Summary method for lpmec objects

Description

Provides a comprehensive summary of bootstrapped LPMEC model results including OLS, IV, corrected, and Bayesian coefficient estimates with confidence intervals.

Usage

# S3 method for lpmec
summary(object, ...)

Value

A data frame containing coefficient estimates, standard errors, and confidence intervals, returned invisibly. The data frame has rows for OLS, IV, Corrected IV, Corrected OLS, and Bayesian OLS estimates.

Arguments

object

An object of class lpmec returned by lpmec.

...

Additional arguments (currently unused).

See Also

lpmec, print.lpmec, plot.lpmec